@@ -15,38 +15,38 @@ class __TQL:
         else:
             print(f"[{__username}] Authentificated User.")
 
-    @staticmethod
-    def load_pkl(dest):
+    @classmethod
+    def load_pkl(cls, dest):
         try:
             with open(dest, 'rb') as f:
                 return pickle.load(f)
         except:
             return None
 
-    @staticmethod
-    def save_pkl(data, dest):
+    @classmethod
+    def save_pkl(cls, data, dest):
         try:
             with open(dest, 'data') as f:
                 pickle.dump(data, f)
         except:
             return None
 
-    @staticmethod
-    def add_user(username):
-        users = __TQL.load_pkl(__TQL.__qdbpath+"authentification.tql")
+    @classmethod
+    def add_user(cls, username):
+        users = cls.load_pkl(cls.__qdbpath+"authentification.tql")
         users.add(username)
-        __TQL.save_pkl(users, __TQL.__qdbpath+"authentification.tql")
+        cls.save_pkl(users, cls.__qdbpath+"authentification.tql")
         print(f"{username} added.")
 
-    @staticmethod
-    def delete_user(username):
-        users = __TQL.load_pkl(__TQL.__qdbpath+"authentification.tql")
+    @classmethod
+    def delete_user(cls, username):
+        users = cls.load_pkl(cls.__qdbpath+"authentification.tql")
         try:
             users.remove(username)
             print(f"{username} deleted.")
         except:
             print(f'{username} does not exists.')
-        __TQL.save_pkl(users, __TQL.__qdbpath+"authentification.tql")
+        cls.save_pkl(users, cls.__qdbpath+"authentification.tql")
         print(f"{username} added.")
 
     
